pub struct UnixSocketAddress(/* private fields */);Expand description
An address associated with a Unix socket.
This type is a thin wrapper around std::os::unix::net::SocketAddr. You
can convert to and from the standard library SocketAddr type using the
From trait. It is also just as easily convertabible to and from a tokio unix SocketAddr.
Implementations
Sourceimpl UnixSocketAddress
impl UnixSocketAddress
Sourcepub fn is_unnamed(&self) -> bool
Available on target_family=unix only.
pub fn is_unnamed(&self) -> bool
target_family=unix only.Returns true if the address is unnamed.
Documentation reflected in SocketAddr
Sourcepub fn as_pathname(&self) -> Option<&Path>
Available on target_family=unix only.
pub fn as_pathname(&self) -> Option<&Path>
target_family=unix only.Returns the contents of this address if it is a pathname address.
Documentation reflected in SocketAddr